<?php
//
// +----------------------------------------------------------------------+
// |Image Handler for zen-cart Open Source E-commerce                     |
// +----------------------------------------------------------------------+
// | Copyright (c) 2005 Tim Kroeger                                       |
// | http://www.breakmyzencart.com                                        |
// |                                                                      |
// |                                                                      |
// |                                                                      |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE.txt, and is    |
// | available through the world-wide-web at the following url:           |
// | http://www.gnu.org/licenses/gpl.txt                                  |
// | If you did not receive a copy of the license and are unable          |
// | to obtain it through the world-wide-web, please send a note to       |
// | tim@breakmyzencart.com so I can mail you a copy immediately.         |
// +----------------------------------------------------------------------+
// $Id: functions_images.php,v 1.1.2.17 2005/05/21 20:48:08 tim Exp $

/**	
 * Manage creation of uploaded (product) images.
 * @author	Tim Kroeger <tim@breakmyzencart.com>
 * @version	1.0-beta1
 */
 
require(DIR_FS_CATALOG . 'includes/functions/extra_functions/functions_images.php');

/**
 * Process uploaded image (resizing) according to configuration settings made
 * in admin->configuration->images
 */
function zen_process_uploaded_image($uploaded_image_name, $previous_image = '') {
	global $messageStack;
	$image_name = ($previous_image == '') ? $uploaded_image_name : $previous_image;
	
	// test if either ImageMagick or GD is selected
	if ((IMAGE_MANAGER_HANDLER) && ((IMAGE_MANAGER_HANDLER == 'ImageMagick') || (IMAGE_MANAGER_HANDLER == 'GD'))) {
		//set sizes for future images
		list($small_width, $small_height, $resize_small) = zen_calculate_image_size(DIR_FS_CATALOG_IMAGES . $uploaded_image_name, SMALL_IMAGE_WIDTH, SMALL_IMAGE_HEIGHT);
		$small_size  = $small_width . "x" . $small_height;

		list($medium_width, $medium_height, $resize_medium) = zen_calculate_image_size(DIR_FS_CATALOG_IMAGES . $uploaded_image_name, MEDIUM_IMAGE_WIDTH, MEDIUM_IMAGE_HEIGHT);
		$medium_size  = $medium_width . "x" . $medium_height;
		// don't change size for large images (take from original)
		list($large_width, $large_height, $resize_large) = zen_calculate_image_size(DIR_FS_CATALOG_IMAGES . $uploaded_image_name, LARGE_IMAGE_MAX_WIDTH, LARGE_IMAGE_MAX_HEIGHT);
		$large_size = $large_width . 'x' . $large_height;
	
		$source_name = DIR_FS_CATALOG_IMAGES . $uploaded_image_name;


		// calculate image extensions
		$image_extension = substr($image_name, strrpos($image_name, '.'));
		$small_file_extension = ((SMALL_IMAGE_FILETYPE == 'no_change') ? $image_extension : '.' . SMALL_IMAGE_FILETYPE);
		$medium_file_extension = ((MEDIUM_IMAGE_FILETYPE == 'no_change') ? $image_extension : '.' . MEDIUM_IMAGE_FILETYPE);
		$large_file_extension = ((LARGE_IMAGE_FILETYPE == 'no_change') ? $image_extension : '.' . LARGE_IMAGE_FILETYPE);
	
		// get image base by stripping off image extension
		$uploaded_image_extension = substr($uploaded_image_name, strrpos($uploaded_image_name, '.'));
		$uploaded_image_base = ereg_replace($uploaded_image_extension . '$', '', $uploaded_image_name);

		// if there's no previous image given we want to update or insert a product's picture
		if ($previous_image == '') {
			//compose filenames for future images
			$image_small = DIR_FS_CATALOG_IMAGES . $uploaded_image_base . $small_file_extension;
			$image_medium = DIR_FS_CATALOG_IMAGES . 'medium/' . $uploaded_image_base . IMAGE_SUFFIX_MEDIUM . $medium_file_extension;
			$image_large = DIR_FS_CATALOG_IMAGES . 'large/' . $uploaded_image_base . IMAGE_SUFFIX_LARGE . $large_file_extension;
			//set filename according to new generated file (strip to relative path first)
			$image_name = ereg_replace(DIR_FS_CATALOG_IMAGES, '', $image_small);
		} 
		// if a previous image is given, we want to add the uploaded image as an additionial image 
		else {
			//calculate image suffix for additional image from uploaded image (strip path and extension)
			$additional_image_suffix = "_" . basename($uploaded_image_name, $uploaded_image_extension);
			$previous_image_extension = substr($previous_image, strrpos($previous_image, '.'));			 
			$previous_image_base = ereg_replace($previous_image_extension . '$', '', $previous_image);
			//compose filenames for future images
			$image_small = DIR_FS_CATALOG_IMAGES . $previous_image_base . $additional_image_suffix . $small_file_extension;
			$image_medium = DIR_FS_CATALOG_IMAGES . 'medium/' . $previous_image_base . $additional_image_suffix . IMAGE_SUFFIX_MEDIUM . $medium_file_extension;
			$image_large = DIR_FS_CATALOG_IMAGES . 'large/' . $previous_image_base . $additional_image_suffix . IMAGE_SUFFIX_LARGE . $large_file_extension;
		}
		bmz_set_visible($image_large);
	
		// generate directory for original image (not needed anymore after generation)
		mkdirr(DIR_FS_CATALOG_IMAGES . "original/" . dirname($uploaded_image_name));
	
		// move original image away
		$destination_name = DIR_FS_CATALOG_IMAGES . "original/" . $uploaded_image_name;
		bmz_set_visible($destination_name);
		if (is_file($destination_name)) {
			@unlink($destination_name);
		}
		rename($source_name, $destination_name);
		bmz_set_visible($destination_name);
		$source_name = $destination_name;
		
		// create directory for medium image
		mkdirr(dirname($image_medium));
		// create directory for large image
		mkdirr(dirname($image_large));

		// Now proceed either with ImageMagick or GD library for resizing
		if (IMAGE_MANAGER_HANDLER == 'ImageMagick') {
			if ((((file_exists(DIR_FS_IMAGE_MAGICK . 'convert')) && (file_exists(DIR_FS_IMAGE_MAGICK . 'composite')) && (file_exists(DIR_FS_IMAGE_MAGICK . 'montage'))))
				|| ((file_exists(DIR_FS_IMAGE_MAGICK . 'convert.exe')) && (file_exists(DIR_FS_IMAGE_MAGICK . 'composite.exe')) && (file_exists(DIR_FS_IMAGE_MAGICK . 'montage.exe')))) {
				zen_imagemagick_resize_image($source_name, $image_small, SMALL_IMAGE_BACKGROUND, $small_size, intval(SMALL_IMAGE_QUALITY));
				zen_imagemagick_resize_image($source_name, $image_medium, MEDIUM_IMAGE_BACKGROUND, $medium_size, intval(MEDIUM_IMAGE_QUALITY));
				if ((($uploaded_image_extension == '.jpg') || ($uploaded_image_extension == '.jpeg')) 
						&& ($large_file_extension == $uploaded_image_extension)
						&& !$resize_large) {
					copy($source_name, $image_large);
					bmz_set_visible($image_large);
				} else {
					zen_imagemagick_resize_image($source_name, $image_large, LARGE_IMAGE_BACKGROUND, $large_size, intval(LARGE_IMAGE_QUALITY));
				}
			} else {
				zen_add_message(ERROR_IMAGE_MAGICK_NOT_FOUND, 'error');
			}
		} elseif (IMAGE_MANAGER_HANDLER == 'GD') {
			zen_gd_resize_image($source_name, $image_small, SMALL_IMAGE_BACKGROUND, $small_width, $small_height, intval(SMALL_IMAGE_QUALITY));
			zen_gd_resize_image($source_name, $image_medium, MEDIUM_IMAGE_BACKGROUND, $medium_width, $medium_height, intval(MEDIUM_IMAGE_QUALITY));
				if ((($uploaded_image_extension == '.jpg') || ($uploaded_image_extension == '.jpeg')) 
						&& ($large_file_extension == $uploaded_image_extension)
						&& !$resize_large) {
				copy($source_name, $image_large);
				bmz_set_visible($image_large);
			} else {
				zen_gd_resize_image($source_name, $image_large, LARGE_IMAGE_BACKGROUND, $large_width, $large_height, intval(LARGE_IMAGE_QUALITY));
			}
		}
	}
	return $image_name;
}
?>